@@ -64,8 +64,8 @@ class Pound(object):
         for l in self.options['backends'].split("\n"):
             l = l.strip()
             if l: vars['backends'].append(dict(zip(['address', 'port'], l.split(":", 1))))
-        if not os.path.exists(outputdir):
-            os.mkdir(outputdir)
+        if not os.path.exists(self.outputdir):
+            os.mkdir(self.outputdir)
         template = open(self.template).read()
         c = Template(template, searchList = vars)
         open(self.cfgfile, 'w').write(str(c))
